@@ -2,11 +2,20 @@
 #ifndef PFTP_DEFAULT_H
 #define PFTP_DEFAULT_H
 
-typedef struct pftp_default_s *pftp_default_t;
+#ifndef LIBPFTP_API
+# ifdef WIN32
+#  include "w32-libpftp.h"
+# else
+#  define LIBPFTP_API 
+# endif
+#endif
 
-struct pftp_default_s {
+LIBPFTP_API typedef struct pftp_default_s *pftp_default_t;
+
+LIBPFTP_API struct pftp_default_s {
     int pasv;    
     int secure_list, secure_data, use_secure, implicid_ssl;
+    int sftp;
     
     uint16_t port_start, port_stop;
     char *bind_to, *myaddr;
