@@ -2,9 +2,17 @@
 #ifndef PFTP_SETTINGS_H
 #define PFTP_SETTINGS_H
 
+#ifndef LIBPFTP_API
+# ifdef WIN32
+#  include "w32-libpftp.h"
+# else
+#  define LIBPFTP_API 
+# endif
+#endif
+
 #include "pftp_default.h"
 
-struct pftp_settings_s {
+LIBPFTP_API struct pftp_settings_s {
     /* can't have defaults */
     uint16_t *port;  
     char **hostname;
@@ -14,6 +22,7 @@ struct pftp_settings_s {
     /* 0 = false, 1 = true, -1 = default/unknown */
     int pasv;    
     int secure_list, secure_data, use_secure, implicid_ssl;
+    int sftp;
     
     /* 0 = default */
     uint16_t port_start, port_stop;
@@ -31,6 +40,6 @@ struct pftp_settings_s {
     void *userdata;
 };
 
-typedef struct pftp_settings_s *pftp_settings_t;
+LIBPFTP_API typedef struct pftp_settings_s *pftp_settings_t;
 
 #endif /* PFTP_SETTINGS_H */
